from __future__ import absolute_import
import inspect

from qgis.core import QgsMessageLog, Qgis
from qgis.gui import QgsMessageBar


class Singleton(type):
    _instances = {}

    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
        return cls._instances[cls]


class CtrlCraftLogger(object, metaclass=Singleton):

    def log(self, msg='', level=None):
        stack = inspect.stack()
        class_name = stack[1][0].f_locals["self"].__class__
        method_name = stack[1][0].f_code.co_name

        msg = '{}::{} : {}'.format(class_name, method_name, msg)
        QgsMessageLog.logMessage(msg, self.name)

    def logBar(self, msg, level=Qgis.Info):
        self.iface.messageBar().pushMessage('', msg, level=level)
