# -*- coding: utf-8 -*-
"""
/***************************************************************************
 CtrlCraftDialogChartEstimatedBlocs
                                 A QGIS plugin
 Areva - plugin for displaying 3D mines
                             -------------------
        begin                : 2017-09-12
        git sha              : $Format:%H$
        copyright            : (C) 2017 by Oslandia
        email                : sylvain.beorchia@oslandia.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
"""

from builtins import range
import os

from PyQt5 import uic
from PyQt5.QtWidgets import (QTableWidget,
                         QTableWidgetItem,
                         QDialog)
from PyQt5.QtGui import QColor

import matplotlib.pyplot as plt
from matplotlib.backends.backend_qt4agg import FigureCanvasQTAgg as FigureCanvas
from matplotlib.backends.backend_qt4agg import NavigationToolbar2QT as NavigationToolbar

from qgis.core import QgsGeometry

FORM_CLASS, _ = uic.loadUiType(os.path.join(
    os.path.dirname(__file__), 'ui', 'chart.ui'))


class CtrlCraftOfficeEstimatedBlocsTable(QDialog, FORM_CLASS):

    """
    Displays a row for each slab within the current deposit/panel/blast with
    its corresponding radiometry as well as its estimated bloc's radiometry and
    sample number.
    """

    def __init__(self, data, parent=None):
        super(CtrlCraftOfficeEstimatedBlocsTable, self).__init__(parent)
        self.setupUi(self)
        self.data = data

    def init(self, deposit, panel, blast):
        # Read DB Slab / panel data
        records = self.data.estimated_blocs_stats_for_slabs(deposit, panel, blast)

        # Build the table
        table = QTableWidget()

        # initiate table
        table.setRowCount(len(records))
        nbCols = 3
        table.setColumnCount(nbCols)

        table.setHorizontalHeaderLabels(( self.tr('Slab estimated grade'),
                                          self.tr('Bloc estimated grade'),
                                          self.tr('Bloc sample number')))
        colColors = [QColor(246, 255, 213), QColor(255, 170, 170), None]

        item = table.horizontalHeaderItem(0)
        item.setToolTip(self.tr('Estimated grade for a slab'))

        item = table.horizontalHeaderItem(1)
        item.setToolTip(self.tr('Estimated grade for the corresponding estimated bloc'))

        item = table.horizontalHeaderItem(2)
        item.setToolTip(self.tr('Sample number of the corresponding estimated bloc'))

        # set data
        tRow = 0
        for r in records:
            for col in range(0, nbCols):
                table.setItem(tRow, col, QTableWidgetItem(r[col]))
                if colColors[col]:
                    table.item(tRow, col).setBackground(colColors[col])
            tRow += 1

        table.horizontalHeader().setStretchLastSection(True)
        table.resizeColumnsToContents()

        # show table
        self.vLayout.addWidget(table)
